@@ -1,6 +1,3 @@
-try(library(dbplyr), silent = TRUE)
-library(rprojroot)
-
 if (!is_attached("dm_cache")) {
   ((attach))(new_environment(), pos = length(search()) - 1, name = "dm_cache")
 }
@@ -77,12 +74,12 @@ my_test_src_cache %<--% {
 my_test_src <- function() {
   fun <- my_test_src_fun()
   if (is.null(fun)) {
-    skip(paste0("Data source not known: ", my_test_src_name))
+    abort(paste0("Data source not known: ", my_test_src_name))
   }
   tryCatch(
     my_test_src_cache(),
     error = function(e) {
-      skip(paste0("Data source ", my_test_src_name, " not accessible: ", conditionMessage(e)))
+      abort(paste0("Data source ", my_test_src_name, " not accessible: ", conditionMessage(e)))
     }
   )
 }
