@@ -4,7 +4,7 @@ knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
-fansi::set_knit_hooks(knitr::knit_hooks)
+fansi::set_knit_hooks(knitr::knit_hooks, which = c("output", "message"))
 options(crayon.enabled = TRUE, width = 75, cli.width = 75)
 
 knit_print.grViz <- function(x, ...) {
